# -*- coding: utf-8 -*-
"""
Merge data from the sessions, Prolific profiles, and the pre-screening
questionnaire and create analysis files.

We collect 1) effort and activity experiences for future self-related activites, 
and 2) the effort spent on all activities.

Required files:
    - Raw_Data/prescreening_questionnaire_multistudypaper_anonym.csv
    - Raw_Data/prolific_profile_multistudypaper_anonym.csv
    - Raw_Data/sessionsdata_multistudypaper_anonym.csv
    
Output files:
    - effort_data_all_activities_human_inv_multistudypaper.csv
    - merged_data_human_inv_multistudypaper.xlsx
    

Author: Nele Albers
Date: May 2024
"""

import pandas as pd


if __name__ == "__main__":
    
    # Indices of future self-related (i.e., identity-related) activities
    IDENTITY_ACTIVITY_INDICES = [3, 4, 17, 18, 19, 20, 23, 24]

    
    # Number of sessions with the virtual coach
    NUM_SESSIONS = 5


    ### Load data
    df_session = pd.read_csv("Raw_Data/sessionsdata_multistudypaper_anonym.csv")
    df_prolific = pd.read_csv("Raw_Data/prolific_profile_multistudypaper_anonym.csv")
    df_prescreening = pd.read_csv("Raw_Data/prescreening_questionnaire_multistudypaper_anonym.csv")


    ### Collect data
    # Only collect these variables for identity-related activities
    session_nums_identity = []
    all_efforts_identity = []
    all_ids_identity = []
    all_activities_identity = []
    all_activity_experiences_identity = []
    all_activity_experiences_mod_identity = []
    # Also collect the effort for all activities
    all_efforts = []
    all_activities = []


    for session in range(1, NUM_SESSIONS):
        
        # All IDs of people with at least an answer to the effort in the next session
        all_session_ids = list(set(df_session[(df_session["session_num"] == session + 1) & (df_session["response_type"] == "effort")]["rand_id"].to_list()))

        for i in all_session_ids:

            # Get data from this person
            df_id = df_session[df_session["rand_id"] == i]

            # Get the index of the assigned activity
            activity = int(df_id[(df_id["session_num"] == session) & (df_id["response_type"] == "activity_new_index")]["response_value"])

            all_efforts.append(int(df_id[(df_id["session_num"] == session + 1) & (df_id["response_type"] == "effort")]["response_value"]))
            all_activities.append(activity)

            # Only for future self-related activities
            if activity in IDENTITY_ACTIVITY_INDICES:

                session_nums_identity.append(session)
                all_efforts_identity.append(int(df_id[(df_id["session_num"] == session + 1) & (df_id["response_type"] == "effort")]["response_value"]))
                all_activities_identity.append(activity)

                # We might not have data on the activity experience or its modification
                df_id_next = df_session[(df_session["session_num"] == session + 1) & (df_session["rand_id"] == i)]
                if "activity_experience_slot" in df_id_next["response_type"].to_list():
                    all_activity_experiences_identity.append(df_id[(df_id["session_num"] == session + 1) & (df_id["response_type"] == "activity_experience_slot")]["response_value"].iloc[0])
                else:
                    all_activity_experiences_identity.append("")
                if "activity_experience_mod_slot" in df_id_next["response_type"].to_list():
                    all_activity_experiences_mod_identity.append(df_id[(df_id["session_num"] == session + 1) & (df_id["response_type"] == "activity_experience_mod_slot")]["response_value"].iloc[0])
                else:
                    all_activity_experiences_mod_identity.append("")

                all_ids_identity.append(i)


    # Create dataframe with samples on future self-related activities
    df_merged = pd.DataFrame()
    df_merged["rand_id"] = all_ids_identity
    df_merged["session"] = session_nums_identity
    df_merged["activity"] = all_activities_identity
    df_merged["effort"] = all_efforts_identity
    df_merged["activity_experience"] = all_activity_experiences_identity
    df_merged["activity_experience_mod"] = all_activity_experiences_mod_identity


    # Now we also want to add the characteristics of the people corresponding to the samples
    df_merged = pd.merge(df_merged, df_prolific, on = "rand_id")
    df_merged = pd.merge(df_merged, df_prescreening, on = "rand_id")

    df_merged.to_excel("merged_data_human_inv_multistudypaper.xlsx", 
                       index=False)


    # And create another dataframe with just the effort scores for all activities
    df_all = pd.DataFrame()
    df_all["effort"] = all_efforts
    df_all["activity"] = all_activities

    df_all.to_csv("effort_data_all_activities_human_inv_multistudypaper.csv",
                  index=False)
